==> seedsui-react-2.6.2.tgz: package/es/Player/Player.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Device from '../Device';
import FullScreen from '../FullScreen';
import MediaUtil from '../MediaUtil';

var Player = (_temp = _class = function (_Component) {
  _inherits(Player, _Component);

  function Player(props) {
    _classCallCheck(this, Player);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.onClick = function (e) {
      if (_this.props.onClick) {
        _this.props.onClick(Object.getArgs(e, _this.props.args));
      } else {
        var target = e.currentTarget.querySelector('video');
        FullScreen.enter(target);

        setTimeout(function () {
          target.play();
        }, 500);
      }
      e.stopPropagation();
    };

    _this.getType = function () {
      var src = _this.props.src;

      return MediaUtil.sourceType(src);
    };

    return _this;
  }

  Player.prototype.componentDidMount = function componentDidMount() {
    var video = this.$video;
    FullScreen.addHandler(video, function (e) {
      if (FullScreen.isFull(video)) {
        video.play();
      } else {
        video.pause();
      }
    });
  };

  Player.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        args = _props.args,
        children = _props.children,
        style = _props.style,
        className = _props.className,
        src = _props.src,
        onClick = _props.onClick,
        others = _objectWithoutProperties(_props, ['args', 'children', 'style', 'className', 'src', 'onClick']);
    // Andriod


    if (Device.os === 'andriod' || onClick) {
      return React.createElement(
        'div',
        { ref: function ref(el) {
            _this2.$el = el;
          }, className: 'player-thumbnail' + (className ? ' ' + className : ''), style: style, onClick: this.onClick },
        !onClick && React.createElement(
          'video',
          _extends({ ref: function ref(el) {
              _this2.$video = el;
            } }, others),
          React.createElement('source', { src: src, type: this.getType() }),
          '\u60A8\u7684\u6D4F\u89C8\u5668\u4E0D\u652F\u6301 video \u6807\u7B7E\u3002'
        ),
        this.props.poster && React.createElement('div', { style: { backgroundImage: 'url(' + this.props.poster + ')' }, className: 'player-thumbnail-poster' }),
        React.createElement('div', { className: 'player-thumbnail-button' }),
        children
      );
    }
    // Ios
    return React.createElement(
      'div',
      { ref: function ref(el) {
          _this2.$el = el;
        }, className: 'player-thumbnail' + (className ? ' ' + className : ''), style: style },
      React.createElement(
        'video',
        _extends({ controls: true, ref: function ref(el) {
            _this2.$video = el;
          } }, others),
        React.createElement('source', { src: src, type: this.getType() }),
        '\u60A8\u7684\u6D4F\u89C8\u5668\u4E0D\u652F\u6301 video \u6807\u7B7E\u3002'
      ),
      children
    );
  };

  return Player;
}(Component), _class.defaultProps = {}, _temp);
export { Player as default };
Player.propTypes = process.env.NODE_ENV !== "production" ? {
  args: PropTypes.any,
  style: PropTypes.object,
  className: PropTypes.string,
  children: PropTypes.node,

  src: PropTypes.string,
  onClick: PropTypes.func
} : {};

==> seedsui-react-2.7.9.tgz: package/es/Player/Player.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Device from '../Device';
import FullScreen from '../FullScreen';
import MediaUtil from '../MediaUtil';

var Player = (_temp = _class = function (_Component) {
  _inherits(Player, _Component);

  function Player(props) {
    _classCallCheck(this, Player);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.onClick = function (e) {
      if (_this.props.onClick) {
        _this.props.onClick(e);
        return;
      }
      var target = e.currentTarget.querySelector('video');
      FullScreen.enter(target);

      setTimeout(function () {
        target.play();
      }, 500);
      e.stopPropagation();
    };

    _this.getType = function () {
      var src = _this.props.src;

      return MediaUtil.sourceType(src);
    };

    return _this;
  }

  Player.prototype.componentDidMount = function componentDidMount() {
    var video = this.$video;
    FullScreen.addHandler(video, function (e) {
      if (FullScreen.isFull(video)) {
        video.play();
      } else {
        video.pause();
      }
    });
  };
  // 默认点击预览

  // 获取媒体类型


  Player.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        src = _props.src,
        poster = _props.poster,
        _props$videoAttribute = _props.videoAttribute,
        videoAttribute = _props$videoAttribute === undefined ? {} : _props$videoAttribute,
        onClick = _props.onClick,
        children = _props.children,
        others = _objectWithoutProperties(_props, ['src', 'poster', 'videoAttribute', 'onClick', 'children']);
    // Andriod


    if (Device.os === 'andriod' || onClick) {
      return React.createElement(
        'div',
        _extends({ ref: function ref(el) {
            _this2.$el = el;
          } }, others, { className: 'player-thumbnail' + (others.className ? ' ' + others.className : ''), onClick: this.onClick }),
        React.createElement(
          'video',
          _extends({ ref: function ref(el) {
              _this2.$video = el;
            } }, videoAttribute, { className: 'player-thumbnail-video' + (others.videoAttribute ? ' ' + others.videoAttribute : '') }),
          React.createElement('source', { src: src, type: this.getType() }),
          '\u60A8\u7684\u6D4F\u89C8\u5668\u4E0D\u652F\u6301 video \u6807\u7B7E\u3002'
        ),
        poster && React.createElement('div', { style: { backgroundImage: 'url(' + poster + ')' }, className: 'player-thumbnail-poster' }),
        React.createElement('div', { className: 'player-thumbnail-button' }),
        children
      );
    }
    // Ios
    return React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, others, { className: 'player-thumbnail' + (others.className ? ' ' + others.className : '') }),
      React.createElement(
        'video',
        _extends({ controls: true, ref: function ref(el) {
            _this2.$video = el;
          } }, videoAttribute, { className: 'player-thumbnail-video' + (others.videoAttribute ? ' ' + others.videoAttribute : '') }),
        React.createElement('source', { src: src, type: this.getType() }),
        '\u60A8\u7684\u6D4F\u89C8\u5668\u4E0D\u652F\u6301 video \u6807\u7B7E\u3002'
      ),
      children
    );
  };

  return Player;
}(Component), _class.defaultProps = {}, _temp);
export { Player as default };
Player.propTypes = process.env.NODE_ENV !== "production" ? {
  src: PropTypes.string,
  poster: PropTypes.string,
  videoAttribute: PropTypes.object,
  onClick: PropTypes.func,
  children: PropTypes.node
} : {};
